package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleState;
import javax.accessibility.AccessibleStateSet;
import javax.accessibility.AccessibleValue;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.awt.Graphics;
import javax.swing.plaf.SplitPaneUI;
import java.beans.ConstructorProperties;
import java.awt.Component;
import javax.accessibility.Accessible;

public class JSplitPane extends JComponent implements Accessible
{
    private static final String uiClassID = "SplitPaneUI";
    public static final int VERTICAL_SPLIT = 0;
    public static final int HORIZONTAL_SPLIT = 1;
    public static final String LEFT = "left";
    public static final String RIGHT = "right";
    public static final String TOP = "top";
    public static final String BOTTOM = "bottom";
    public static final String DIVIDER = "divider";
    public static final String ORIENTATION_PROPERTY = "orientation";
    public static final String CONTINUOUS_LAYOUT_PROPERTY = "continuousLayout";
    public static final String DIVIDER_SIZE_PROPERTY = "dividerSize";
    public static final String ONE_TOUCH_EXPANDABLE_PROPERTY = "oneTouchExpandable";
    public static final String LAST_DIVIDER_LOCATION_PROPERTY = "lastDividerLocation";
    public static final String DIVIDER_LOCATION_PROPERTY = "dividerLocation";
    public static final String RESIZE_WEIGHT_PROPERTY = "resizeWeight";
    protected int orientation;
    protected boolean continuousLayout;
    protected Component leftComponent;
    protected Component rightComponent;
    protected int dividerSize;
    private boolean dividerSizeSet;
    protected boolean oneTouchExpandable;
    private boolean oneTouchExpandableSet;
    protected int lastDividerLocation;
    private double resizeWeight;
    private int dividerLocation;
    
    public JSplitPane() {
        this(1, UIManager.getBoolean("SplitPane.continuousLayout"), new JButton(UIManager.getString("SplitPane.leftButtonText")), new JButton(UIManager.getString("SplitPane.rightButtonText")));
    }
    
    @ConstructorProperties({ "orientation" })
    public JSplitPane(int n) {
        this(n, UIManager.getBoolean("SplitPane.continuousLayout"));
    }
    
    public JSplitPane(int n, boolean b) {
        this(n, b, null, null);
    }
    
    public JSplitPane(int n, Component component, Component component2) {
        this(n, UIManager.getBoolean("SplitPane.continuousLayout"), component, component2);
    }
    
    public JSplitPane(int orientation, boolean continuousLayout, Component leftComponent, Component rightComponent) {
        this.dividerSizeSet = false;
        this.dividerLocation = -1;
        this.setLayout(null);
        this.setUIProperty("opaque", Boolean.TRUE);
        this.orientation = orientation;
        if (this.orientation != 1 && this.orientation != 0) {
            throw new IllegalArgumentException("cannot create JSplitPane, orientation must be one of JSplitPane.HORIZONTAL_SPLIT or JSplitPane.VERTICAL_SPLIT");
        }
        this.continuousLayout = continuousLayout;
        if (leftComponent != null) {
            this.setLeftComponent(leftComponent);
        }
        if (rightComponent != null) {
            this.setRightComponent(rightComponent);
        }
        this.updateUI();
        return;
    }
    
    public void setUI(SplitPaneUI ui) {
        if ((SplitPaneUI)this.ui != ui) {
            super.setUI(ui);
            this.revalidate();
        }
    }
    
    public SplitPaneUI getUI() {
        return (SplitPaneUI)this.ui;
    }
    
    @Override
    public void updateUI() {
        this.setUI((SplitPaneUI)UIManager.getUI(this));
        this.revalidate();
    }
    
    @Override
    public String getUIClassID() {
        return "SplitPaneUI";
    }
    
    public void setDividerSize(int dividerSize) {
        int dividerSize2 = this.dividerSize;
        this.dividerSizeSet = true;
        if (dividerSize2 != dividerSize) {
            this.firePropertyChange("dividerSize", dividerSize2, this.dividerSize = dividerSize);
        }
    }
    
    public int getDividerSize() {
        return this.dividerSize;
    }
    
    public void setLeftComponent(Component comp) {
        if (comp == null) {
            if (this.leftComponent != null) {
                this.remove(this.leftComponent);
                this.leftComponent = null;
            }
        }
        else {
            this.add(comp, "left");
        }
    }
    
    public Component getLeftComponent() {
        return this.leftComponent;
    }
    
    public void setTopComponent(Component leftComponent) {
        this.setLeftComponent(leftComponent);
    }
    
    public Component getTopComponent() {
        return this.leftComponent;
    }
    
    public void setRightComponent(Component comp) {
        if (comp == null) {
            if (this.rightComponent != null) {
                this.remove(this.rightComponent);
                this.rightComponent = null;
            }
        }
        else {
            this.add(comp, "right");
        }
    }
    
    public Component getRightComponent() {
        return this.rightComponent;
    }
    
    public void setBottomComponent(Component rightComponent) {
        this.setRightComponent(rightComponent);
    }
    
    public Component getBottomComponent() {
        return this.rightComponent;
    }
    
    public void setOneTouchExpandable(boolean oneTouchExpandable) {
        int oneTouchExpandable2 = this.oneTouchExpandable;
        this.oneTouchExpandable = oneTouchExpandable;
        this.oneTouchExpandableSet = true;
        this.firePropertyChange("oneTouchExpandable", (boolean)oneTouchExpandable2, oneTouchExpandable);
        this.repaint();
    }
    
    public boolean isOneTouchExpandable() {
        return this.oneTouchExpandable;
    }
    
    public void setLastDividerLocation(int lastDividerLocation) {
        this.firePropertyChange("lastDividerLocation", this.lastDividerLocation, this.lastDividerLocation = lastDividerLocation);
    }
    
    public int getLastDividerLocation() {
        return this.lastDividerLocation;
    }
    
    public void setOrientation(int orientation) {
        if (orientation != 0 && orientation != 1) {
            throw new IllegalArgumentException("JSplitPane: orientation must be one of JSplitPane.VERTICAL_SPLIT or JSplitPane.HORIZONTAL_SPLIT");
        }
        this.firePropertyChange("orientation", this.orientation, this.orientation = orientation);
        return;
    }
    
    public int getOrientation() {
        return this.orientation;
    }
    
    public void setContinuousLayout(boolean continuousLayout) {
        this.firePropertyChange("continuousLayout", this.continuousLayout, this.continuousLayout = continuousLayout);
    }
    
    public boolean isContinuousLayout() {
        return this.continuousLayout;
    }
    
    public void setResizeWeight(double resizeWeight) {
        if (resizeWeight < 0.0 || resizeWeight > 1.0) {
            throw new IllegalArgumentException("JSplitPane weight must be between 0 and 1");
        }
        this.firePropertyChange("resizeWeight", this.resizeWeight, this.resizeWeight = resizeWeight);
        return;
    }
    
    public double getResizeWeight() {
        return this.resizeWeight;
    }
    
    public void resetToPreferredSizes() {
        SplitPaneUI ui = this.getUI();
        if (ui != null) {
            ui.resetToPreferredSizes(this);
        }
    }
    
    public void setDividerLocation(double n) {
        if (n < 0.0 || n > 1.0) {
            throw new IllegalArgumentException("proportional location must be between 0.0 and 1.0.");
        }
        if (this.getOrientation() == 0) {
            this.setDividerLocation((int)((double)(this.getHeight() - this.getDividerSize()) * n));
        }
        else {
            this.setDividerLocation((int)((double)(this.getWidth() - this.getDividerSize()) * n));
        }
        return;
    }
    
    public void setDividerLocation(int dividerLocation) {
        int dividerLocation2 = this.dividerLocation;
        this.dividerLocation = dividerLocation;
        SplitPaneUI ui = this.getUI();
        if (ui != null) {
            ui.setDividerLocation(this, dividerLocation);
        }
        this.firePropertyChange("dividerLocation", dividerLocation2, dividerLocation);
        this.setLastDividerLocation(dividerLocation2);
    }
    
    public int getDividerLocation() {
        return this.dividerLocation;
    }
    
    public int getMinimumDividerLocation() {
        SplitPaneUI ui = this.getUI();
        if (ui != null) {
            return ui.getMinimumDividerLocation(this);
        }
        return -1;
    }
    
    public int getMaximumDividerLocation() {
        SplitPaneUI ui = this.getUI();
        if (ui != null) {
            return ui.getMaximumDividerLocation(this);
        }
        return -1;
    }
    
    @Override
    public void remove(Component comp) {
        if (comp == this.leftComponent) {
            this.leftComponent = null;
        }
        else if (comp == this.rightComponent) {
            this.rightComponent = null;
        }
        super.remove(comp);
        this.revalidate();
        this.repaint();
    }
    
    @Override
    public void remove(int n) {
        Component component = this.getComponent(n);
        if (component == this.leftComponent) {
            this.leftComponent = null;
        }
        else if (component == this.rightComponent) {
            this.rightComponent = null;
        }
        super.remove(n);
        this.revalidate();
        this.repaint();
    }
    
    @Override
    public void removeAll() {
        Component component = null;
        this.rightComponent = component;
        this.leftComponent = component;
        super.removeAll();
        this.revalidate();
        this.repaint();
    }
    
    @Override
    public boolean isValidateRoot() {
        return true;
    }
    
    @Override
    protected void addImpl(Component comp, Object constraints, int index) {
        if (constraints != null && !(constraints instanceof String)) {
            throw new IllegalArgumentException("cannot add to layout: constraint must be a string (or null)");
        }
        if (constraints == null) {
            if (this.getLeftComponent() == null) {
                constraints = "left";
            }
            else if (this.getRightComponent() == null) {
                constraints = "right";
            }
        }
        if (constraints != null && (constraints.equals("left") || constraints.equals("top"))) {
            Component leftComponent = this.getLeftComponent();
            if (leftComponent != null) {
                this.remove(leftComponent);
            }
            this.leftComponent = comp;
            index = -1;
        }
        else if (constraints != null && (constraints.equals("right") || constraints.equals("bottom"))) {
            Component rightComponent = this.getRightComponent();
            if (rightComponent != null) {
                this.remove(rightComponent);
            }
            this.rightComponent = comp;
            index = -1;
        }
        else if (constraints != null && constraints.equals("divider")) {
            index = -1;
        }
        super.addImpl(comp, constraints, index);
        this.revalidate();
        this.repaint();
        return;
    }
    
    @Override
    protected void paintChildren(Graphics graphics) {
        super.paintChildren(graphics);
        SplitPaneUI ui = this.getUI();
        if (ui != null) {
            Graphics create = graphics.create();
            ui.finishedPaintingChildren(this, create);
            create.dispose();
        }
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("SplitPaneUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    void setUIProperty(String s, Object o) {
        if (s == "dividerSize") {
            if (!this.dividerSizeSet) {
                this.setDividerSize(((Number)o).intValue());
                this.dividerSizeSet = false;
            }
        }
        else if (s == "oneTouchExpandable") {
            if (!this.oneTouchExpandableSet) {
                this.setOneTouchExpandable((boolean)o);
                this.oneTouchExpandableSet = false;
            }
        }
        else {
            super.setUIProperty(s, o);
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString() + ",continuousLayout=" + (this.continuousLayout ? "true" : "false") + ",dividerSize=" + this.dividerSize + ",lastDividerLocation=" + this.lastDividerLocation + ",oneTouchExpandable=" + (this.oneTouchExpandable ? "true" : "false") + ",orientation=" + ((this.orientation == 1) ? "HORIZONTAL_SPLIT" : "VERTICAL_SPLIT");
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JSplitPane.AccessibleJSplitPane();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJSplitPane extends JComponent.AccessibleJComponent implements AccessibleValue
    {
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            AccessibleStateSet accessibleStateSet = super.getAccessibleStateSet();
            if (JSplitPane.this.getOrientation() == 0) {
                accessibleStateSet.add(AccessibleState.VERTICAL);
                return accessibleStateSet;
            }
            accessibleStateSet.add(AccessibleState.HORIZONTAL);
            return accessibleStateSet;
        }
        
        @Override
        public AccessibleValue getAccessibleValue() {
            return this;
        }
        
        @Override
        public Number getCurrentAccessibleValue() {
            return Integer.valueOf(JSplitPane.this.getDividerLocation());
        }
        
        @Override
        public boolean setCurrentAccessibleValue(Number n) {
            if (n == null) {
                return false;
            }
            JSplitPane.this.setDividerLocation(n.intValue());
            return true;
        }
        
        @Override
        public Number getMinimumAccessibleValue() {
            return Integer.valueOf(JSplitPane.this.getUI().getMinimumDividerLocation(JSplitPane.this));
        }
        
        @Override
        public Number getMaximumAccessibleValue() {
            return Integer.valueOf(JSplitPane.this.getUI().getMaximumDividerLocation(JSplitPane.this));
        }
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.SPLIT_PANE;
        }
    }
}
